@@ -21,13 +21,14 @@ from pathlib import Path
 import click
 import coloredlogs  # type: ignore
 
-from gitws import AppConfig, GitWS
+from gitws import AppConfig, Defaults, GitWS, ManifestSpec
 from gitws._util import resolve_relative
 from gitws.const import MANIFEST_PATH_DEFAULT
 from gitws.git import FileStatus, State
 
 from .common import COLOR_INFO, Context, Error, exceptionhandling, get_loglevel, pass_context
 from .config import config
+from .dep import dep
 from .info import info
 from .manifest import manifest
 from .options import (
@@ -46,6 +47,7 @@ from .options import (
     reverse_option,
     update_option,
 )
+from .remote import remote
 
 _LOGGING_FORMAT = "%(name)s %(levelname)s %(message)s"
 
@@ -111,10 +113,20 @@ def deinit(context):
 @path_option()
 @manifest_option(initial=True)
 @group_filters_option(initial=True)
+@click.option("--revision", help="Revision to be checked out. Tag, Branch or SHA")
 @update_option()
 @force_option()
 @pass_context
-def clone(context, url, path=None, manifest_path=None, group_filters=None, update: bool = False, force: bool = False):
+def clone(
+    context,
+    url,
+    path=None,
+    manifest_path=None,
+    group_filters=None,
+    revision=None,
+    update: bool = False,
+    force: bool = False,
+):
     """
     Create a git clone and initialize Git Workspace.
     """
@@ -125,6 +137,7 @@ def clone(context, url, path=None, manifest_path=None, group_filters=None, updat
             main_path=path,
             manifest_path=manifest_path,
             group_filters=group_filters,
+            revision=revision,
             force=force,
             secho=context.secho,
         )
@@ -388,6 +401,23 @@ def commit(context, manifest_path=None, group_filters=None, paths=None, message=
         gws.commit(message, process_paths(paths), all_=all_)
 
 
+@main.command()
+@click.argument("name")
+@click.option("--message", "-m", help="tag message")
+@manifest_option()
+@group_filters_option()
+@pass_context
+def tag(context, name, manifest_path=None, group_filters=None, message=None):
+    """
+    Create git tag on main repository.
+
+    This includes freezing all dependencies.
+    """
+    with exceptionhandling(context):
+        gws = GitWS.from_path(manifest_path=manifest_path, group_filters=group_filters, secho=context.secho)
+        gws.tag(name, msg=message)
+
+
 @main.command()
 @projects_option()
 @manifest_option()
@@ -427,6 +457,40 @@ def submodule(context, command, projects=None, manifest_path=None, group_filters
         gws.run_foreach(("git", "submodule") + command, project_paths=projects, reverse=reverse)
 
 
+@main.command()
+@manifest_option(initial=True)
+@click.argument("name", type=click.Choice(tuple(Defaults.__fields__)))
+@click.argument("value")
+@pass_context
+def default(context, manifest_path, name, value):
+    """
+    Set Default in Manifest.
+    """
+    with exceptionhandling(context):
+        manifest_path = Path(manifest_path)
+        manifest_spec = ManifestSpec.load(manifest_path)
+        defaults = manifest_spec.defaults.update_fromstr({name: value if value else None})
+        manifest_spec = manifest_spec.update(defaults=defaults)
+        manifest_spec.save(manifest_path)
+
+
+@main.command()
+@manifest_option(initial=True)
+@click.argument("value")
+@pass_context
+def group_filters(context, manifest_path, value):
+    """
+    Set Group Filter.
+    """
+    with exceptionhandling(context):
+        manifest_path = Path(manifest_path)
+        manifest_spec = ManifestSpec.load(manifest_path)
+        manifest_spec = manifest_spec.update_fromstr({"group-filters": value if value else None})
+        manifest_spec.save(manifest_path)
+
+
 main.add_command(config)
 main.add_command(info)
 main.add_command(manifest)
+main.add_command(remote)
+main.add_command(dep)
