@@ -46,7 +46,7 @@ from ._util import add_comment, add_info, as_dict, get_repr, resolve_relative
 from .const import MANIFEST_PATH_DEFAULT
 from .exceptions import ManifestError, ManifestNotFoundError
 
-_RE_GROUP = re.compile(r"\A[a-zA-Z0-9_][a-zA-Z0-9_\-]+\Z")
+_RE_GROUP = re.compile(r"\A[a-zA-Z0-9_][a-zA-Z0-9_\-]*\Z")
 
 ProjectPaths = Tuple[
     str,
@@ -268,7 +268,7 @@ class Defaults(BaseModel):
     """Initialize and Update `git submodules`."""
 
 
-class Project(BaseModel):
+class Project(BaseModel, allow_population_by_field_name=True):
 
     """
     Project.
@@ -467,7 +467,7 @@ class ProjectSpec(BaseModel, allow_population_by_field_name=True):
     path: Optional[str] = None
     """Path within workspace. `name` will be used as default."""
 
-    manifest_path: str = str(MANIFEST_PATH_DEFAULT)
+    manifest_path: Optional[str] = Field(str(MANIFEST_PATH_DEFAULT), alias="manifest-path")
     """Path to the manifest file. Relative to `path`."""
 
     groups: Groups = Groups()
@@ -643,6 +643,18 @@ class ManifestSpec(BaseModel, allow_population_by_field_name=True):
                 raise ValueError(f"Remote name {name!r} is used more than once")
         return values
 
+    @root_validator(allow_reuse=True)
+    def _deps_unique(cls, values):
+        # pylint: disable=no-self-argument,no-self-use
+        names = set()
+        for dep in values.get("dependencies", None) or []:
+            name = dep.name
+            if name not in names:
+                names.add(name)
+            else:
+                raise ValueError(f"Dependency name {name!r} is used more than once")
+        return values
+
     @validator("group_filters", allow_reuse=True)
     def _group_filters(cls, values):
         # pylint: disable=no-self-argument,no-self-use
@@ -671,16 +683,19 @@ class ManifestSpec(BaseModel, allow_population_by_field_name=True):
         except Exception as exc:
             raise ManifestError(resolve_relative(path), str(exc)) from None
 
-    def dump(self, doc: Optional[tomlkit.TOMLDocument] = None, path: Optional[Path] = None) -> str:
+    def dump(
+        self, doc: Optional[tomlkit.TOMLDocument] = None, path: Optional[Path] = None, minimal: bool = False
+    ) -> str:
         """
         Return :any:`ManifestSpec` as string.
 
         The output will include an inline documentation of all available options.
         If `doc` or `path` are specified, any additional attributes and comments are **kept**.
 
-        Args:
+        Keyword Args:
             doc: Existing document to be updated.
             path: Path to possibly existing document.
+            minimal: Skip unset
         """
         assert not doc or not path, "'doc' and 'path' are mutually exclusive."
         if doc is None:
@@ -688,7 +703,18 @@ class ManifestSpec(BaseModel, allow_population_by_field_name=True):
                 doc = tomlkit.parse(path.read_text())
             else:
                 doc = self._create()
-        for key, value in as_dict(self).items():
+        if minimal:
+            data = as_dict(self)
+        else:
+            data = {
+                "version": ManifestSpec().version,
+                "remotes": tomlkit.aot(),
+                "group-filters": tuple(),
+                "defaults": {},
+                "dependencies": tomlkit.aot(),
+            }
+            data.update(as_dict(self))
+        for key, value in data.items():
             doc[key] = value
         return tomlkit.dumps(doc)
 
@@ -727,6 +753,7 @@ class ManifestSpec(BaseModel, allow_population_by_field_name=True):
             newdoc[key] = value
         for key, value in as_dict(obj).items():
             newdoc[key] = value
+        newdoc["version"] = "1.0"
 
         # write
         path.write_text(tomlkit.dumps(newdoc))
@@ -751,14 +778,14 @@ https://git-ws.readthedocs.io/en/latest/manual/manifest.html
 
         # Group Filtering
         example = ManifestSpec(group_filters=GroupFilters(("+test", "-doc", "+feature@path")))
-        add_comment(doc, example.dump(doc=tomlkit.document())[:-1])
+        add_comment(doc, example.dump(doc=tomlkit.document(), minimal=True)[:-1])
         doc.add("group-filters", tomlkit.array())
         doc.add(tomlkit.nl())
         doc.add(tomlkit.nl())
 
         # Remotes
         example = ManifestSpec(remotes=[Remote(name="myremote", url_base="https://github.com/myuser")])
-        add_comment(doc, example.dump(doc=tomlkit.document())[:-1])
+        add_comment(doc, example.dump(doc=tomlkit.document(), minimal=True)[:-1])
         doc.add("remotes", tomlkit.aot())
         doc.add(tomlkit.nl())
         doc.add(tomlkit.nl())
@@ -770,7 +797,7 @@ https://git-ws.readthedocs.io/en/latest/manual/manifest.html
                 remote="myserver", revision="main", groups=("+test",), with_groups=("doc",), submodules=True
             )
         )
-        add_comment(doc, "\n".join(example.dump(doc=tomlkit.document()).split("\n")[1:-1]))
+        add_comment(doc, "\n".join(example.dump(doc=tomlkit.document(), minimal=True).split("\n")[1:-1]))
         doc.add(tomlkit.nl())
         doc.add(tomlkit.nl())
 
@@ -789,7 +816,7 @@ https://git-ws.readthedocs.io/en/latest/manual/manifest.html
                 )
             ]
         )
-        add_comment(doc, example.dump(doc=tomlkit.document())[:-1])
+        add_comment(doc, example.dump(doc=tomlkit.document(), minimal=True)[:-1])
         doc.add(tomlkit.nl())
 
         add_info(doc, "A full flavored dependency using a 'url':")
@@ -805,12 +832,12 @@ https://git-ws.readthedocs.io/en/latest/manual/manifest.html
                 )
             ]
         )
-        add_comment(doc, example.dump(doc=tomlkit.document())[:-1])
+        add_comment(doc, example.dump(doc=tomlkit.document(), minimal=True)[:-1])
         doc.add(tomlkit.nl())
 
         add_info(doc, "A minimal dependency:")
         example = ManifestSpec(dependencies=[ProjectSpec(name="my", submodules=None)])
-        add_comment(doc, example.dump(doc=tomlkit.document())[:-1])
+        add_comment(doc, example.dump(doc=tomlkit.document(), minimal=True)[:-1])
 
         doc.add("dependencies", tomlkit.aot())
 
